@@ -32,7 +32,7 @@
 #include <mce/dbus-names.h>
 #include <mce/mode-names.h>
 
-DesktopWidget::DesktopWidget(QWidget *parent, QString appletId) :
+DesktopWidget::DesktopWidget(QWidget *parent, QString appletId, bool debug) :
     QFrame(parent)
 {
     QCoreApplication::instance()->setApplicationName("Vodafone 190 desktop widget");
@@ -74,7 +74,8 @@ DesktopWidget::DesktopWidget(QWidget *parent, QString appletId) :
     m_UpdateTimer = NULL;
     m_Updating = false;
     m_Vodafone = new VodafoneWidget("", "");
-    m_Vodafone->RequestTimeoutMsec = 30000;
+    m_Vodafone->DebugXml = debug;
+    m_Vodafone->RequestTimeoutMsec = 60000;
 
     m_SettingsWindow = NULL;
     m_Settings = new Settings(this, m_AppletId);
@@ -104,9 +105,8 @@ DesktopWidget::DesktopWidget(QWidget *parent, QString appletId) :
 
     setLayout(m_Layout);
     CreateWidgets();
-    if (loaded){
+    if (loaded)
         m_Vodafone->SetCredentials(m_Settings->Username, m_Settings->Password);
-    }
     SetWidgetSize();
 
 } // DesktopWidget
@@ -122,8 +122,8 @@ DesktopWidget::~DesktopWidget()
     QDBusConnection::systemBus().disconnect("com.nokia.icd", "/com/nokia/icd", "com.nokia.icd",
                                             "status_changed", this, SLOT(netStateChanged(QString,QString,QString,QString)));
 
-    QDBusConnection::systemBus().disconnect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
-                                            MCE_DISPLAY_SIG, this, SLOT(displayStateChanged(QString)));
+    /*QDBusConnection::systemBus().disconnect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
+                                            MCE_DISPLAY_SIG, this, SLOT(displayStateChanged(QString)));*/
 
     if (m_WaitIcon != NULL)
         delete m_WaitIcon;
@@ -135,7 +135,7 @@ void DesktopWidget::show()
 {    
     ShowSavedData();
     QFrame::show();
-    //QTimer::singleShot(1000, this, SLOT(Update()));
+    QTimer::singleShot(1000, this, SLOT(Update()));
 }
 
 void DesktopWidget::CreateTimer()
@@ -348,14 +348,31 @@ bool DesktopWidget::UpdateData()
             }
 
             qDebug() << "Getting counters details";
+            QLabel* lbl = NULL;
             foreach(Counter* c, m_Settings->ShowCounters){
+                lbl = new QLabel(this);
+                lbl->setAlignment(Qt::AlignCenter);
+                StartWaitAnimation(lbl);
+                m_CountersLayout->addWidget(lbl, 0, Qt::AlignTop);
+
                 if (IsNetConnected() && m_Vodafone->GetDettaglioContatore(c)){
+                    StopWaitAnimation(lbl);
+                    QLayoutItem *child = m_CountersLayout->takeAt(m_CountersLayout->count() - 1);
+                    delete child->widget();
+                    delete child;
+
                     c->WidgetSize = m_Settings->CounterStyle;
                     CounterWidget* w = new CounterWidget(this, c, m_Settings);
                     w->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Minimum);
                     m_CountersLayout->addWidget(w, 0, Qt::AlignTop);
                     w->show();
+                }else{
+                    StopWaitAnimation(lbl);
+                    QLayoutItem *child = m_CountersLayout->takeAt(m_CountersLayout->count() - 1);
+                    delete child->widget();
+                    delete child;
                 }
+                lbl = NULL;
             }
         }
 
